package de.theserverside.designpatterns.decorator;

/**
 * Stellt im UML-Klassendiagramm "ConcreteDecorator" dar, die
 * das Verhaltens der Klasse Textdatei ("Component") erweitert.
 */
public class EntitiesUmgewandeltTextdateiDekorierer extends
		TextdateiDekorierer {
	private final Textdatei textdatei;

	/**
	 * Instanziiert die Klasse und sichert die Instanz auf den
	 * nchsthheren Decorator in der Hierarchie.
	 */
	public EntitiesUmgewandeltTextdateiDekorierer(
			Textdatei textdatei) {
		this.textdatei = textdatei;
	}

	/**
	 * Erweitert das Verhalten der Implementation der Klasse
	 * Textdatei, bzw. seiner Implementation in der Klasse
	 * KonkreteTextdatei, um das Umwandeln der Sonderzeichen.
	 */
	@Override
	public String speichern(String dateiname) {
		/*
		 * Reicht die Operation an den nchsthheren Decorator
		 * in der Hierarchie weiter und wendet anschlieend das
		 * erweiterte Verhalten (umwandeln) an.
		 */
		return umwandeln(textdatei.speichern(dateiname));
	}

	/**
	 * Beispielhafte Erweiterung des Verhaltens der Klasse
	 * Textdatei.
	 */
	private String umwandeln(String dateiname) {
		/*
		 * Hier findet das erweiterte Verhalten statt, in diesem
		 * Fall z.B. das Umwandeln von Sonderzeichen in
		 * HTML-Entities. Ein "" wird zum "&Auml;" etc..
		 */
		System.out
				.println("HTML-Entities in der Datei umgewandelt!");
		return dateiname;
	}
}