package de.theserverside.designpatterns.decorator;

/**
 * Stellt im UML-Klassendiagramm "ConcreteDecorator" dar, die
 * das Verhaltens der Klasse Textdatei ("Component") erweitert.
 */
public class KomprimierteTextdateiDekorierer extends
		TextdateiDekorierer {
	private final Textdatei textdatei;

	/**
	 * Instanziiert die Klasse und sichert die Instanz auf den
	 * nchsthheren Decorator in der Hierarchie.
	 */
	public KomprimierteTextdateiDekorierer(Textdatei textdatei) {
		this.textdatei = textdatei;
	}

	/**
	 * Erweitert das Verhalten der Implementation der Klasse
	 * Textdatei, bzw. seiner Implementation in der Klasse
	 * KonkreteTextdatei, um das Komprimieren der Datei.
	 */
	@Override
	public String speichern(String dateiname) {
		/*
		 * Reicht die Operation an den nchsthheren Decorator
		 * in der Hierarchie weiter und wendet anschlieend das
		 * erweiterte Verhalten (komprimieren) an.
		 */
		return komprimieren(textdatei.speichern(dateiname));
	}

	/**
	 * Beispielhafte Erweiterung des Verhaltens der Klasse
	 * Textdatei.
	 */
	private String komprimieren(String dateiname) {
		/*
		 * Hier findet das erweiterte Verhalten statt, in diesem
		 * Fall z.B. das Komprimieren des Datenbankinhalts.
		 */
		System.out.println("Datei komprimiert!");
		return dateiname;
	}
}